@@ -1,6 +1,6 @@
 -- An authenticated sender is accepted, the message is not processed.
 
-conn = mt.connect("inet:3333@localhost")
+local conn = mt.connect("inet:" .. port .. "@127.0.0.1")
 assert(conn, "could not open connection")
 
 local err = mt.conninfo(conn, "client.gluet.ch", "123.123.123.123")
