@@ -1,13 +1,13 @@
 mod common;
 
-pub use common::*;  // `pub` only to silence unused code warnings
+pub use common::*;
 use spamassassin_milter::*;
 
-#[test]
-fn spam_message() {
-    let mut builder = configure_spamc(Config::builder());
-    builder.spamc_args(&[format!("--port={}", SPAMD_PORT)]);
-    let config = builder.build();
+#[tokio::test]
+async fn spam_message() {
+    let config = configure_spamc(Config::builder())
+        .spamc_args(&[format!("--port={}", SPAMD_PORT)])
+        .build();
 
     let server = spawn_mock_spamd_server(SPAMD_PORT, |spam| {
         let mut spam = spam
@@ -36,13 +36,16 @@ fn spam_message() {
         );
 
         Err(spam)
-    });
-    let miltertest = spawn_miltertest_runner(file!());
+    })
+    .await
+    .unwrap();
 
-    run("inet:3333@localhost", config).expect("milter execution failed");
+    let milter = SpamAssassinMilter::spawn(LOCALHOST, config).await.unwrap();
 
-    let exit_code = miltertest.join().expect("panic in miltertest runner");
-    assert!(exit_code.success(), "miltertest returned error exit code");
+    let exit_code = run_miltertest(file!(), milter.addr()).await.unwrap();
 
-    server.join().expect("panic in mock spamd server");
+    milter.shutdown().await.unwrap();
+    server.await.unwrap().unwrap();
+
+    assert!(exit_code.success());
 }
